DynamicQueryRequest

Struct DynamicQueryRequest 

pub struct DynamicQueryRequest {
    pub request_type: DynamicQueryRequestType,
    pub query_name: Option<String>,
    pub query: BatchQuery,
    pub parameters: Option<BTreeMap<String, DynamicQueryValue>>,
    pub parameter_types: Option<BTreeMap<String, QueryParamType>>,
}
Full JSON payload accepted by the gateway dynamic query route.

Fields

request_type: DynamicQueryRequestType

Whether the inline query should execute as a read or write.

query_name: Option<String>

Optional query name used by gateway logs and slow-query diagnostics.

query: BatchQuery

Inline query AST payload.

parameters: Option<BTreeMap<String, DynamicQueryValue>>

Runtime parameters forwarded to the query engine.

parameter_types: Option<BTreeMap<String, QueryParamType>>

Optional parameter schema used by runtimes to coerce typed inputs.

Implementations

Source

impl DynamicQueryRequest

pub fn read(query: ReadBatch) -> Self

Create a dynamic request payload for a read batch.

Examples found in repository?
examples/generate_parity_fixtures.rs (line 61)
60fn read_request(batch: ReadBatch) -> DynamicQueryRequest {
61    DynamicQueryRequest::read(batch)
62}
pub fn write(query: WriteBatch) -> Self

Create a dynamic request payload for a write batch.

Examples found in repository?
examples/generate_parity_fixtures.rs (line 65)
64fn write_request(batch: WriteBatch) -> DynamicQueryRequest {
65    DynamicQueryRequest::write(batch)
66}
pub fn insert_parameter_value( &mut self, name: impl Into<String>, value: DynamicQueryValue, )

Insert a named parameter value into the request payload.

Examples found in repository?
examples/generate_parity_fixtures.rs (line 99)
93fn with_params(
94    mut request: DynamicQueryRequest,
95    values: Vec<(&str, DynamicQueryValue)>,
96    types: Vec<(&str, QueryParamType)>,
97) -> DynamicQueryRequest {
98    for (name, value) in values {
99        request.insert_parameter_value(name, value);
100    }
101    for (name, ty) in types {
102        request.insert_parameter_type(name, ty);
103    }
104    request
105}
pub fn insert_parameter_type( &mut self, name: impl Into<String>, ty: QueryParamType, )

Insert a named parameter type into the request payload.

Examples found in repository?
examples/generate_parity_fixtures.rs (line 102)
93fn with_params(
94    mut request: DynamicQueryRequest,
95    values: Vec<(&str, DynamicQueryValue)>,
96    types: Vec<(&str, QueryParamType)>,
97) -> DynamicQueryRequest {
98    for (name, value) in values {
99        request.insert_parameter_value(name, value);
100    }
101    for (name, ty) in types {
102        request.insert_parameter_type(name, ty);
103    }
104    request
105}
pub fn set_query_name(&mut self, name: impl Into<String>)

Set the query name used by gateway logs and slow-query diagnostics.

pub fn clear_query_name(&mut self)

Clear the query name so JSON serialization emits query_name: null.

pub fn with_parameter_value( self, name: impl Into<String>, value: DynamicQueryValue, ) -> Self

Insert a named parameter value and return the updated request.

pub fn with_parameter_type( self, name: impl Into<String>, ty: QueryParamType, ) -> Self

Insert a named parameter type and return the updated request.

pub fn with_query_name(self, name: impl Into<String>) -> Self

Set the query name and return the updated request.

pub fn to_json_bytes(&self) -> Result<Vec<u8>, DynamicQueryError>

Serialize the request payload to JSON bytes.

pub fn to_json_string(&self) -> Result<String, DynamicQueryError>

Serialize the request payload to a JSON string.

Examples found in repository?
examples/generate_parity_fixtures.rs (line 31)
15fn main() -> Result<(), Box<dyn std::error::Error>> {
16    let out = env::args()
17        .nth(1)
18        .unwrap_or_else(|| "tests/parity/generated/rust".to_string());
19    let out = Path::new(&out);
20    reset_dir(&out.join("runtime"))?;
21    reset_dir(&out.join("json-only"))?;
22
23    let mut fixtures = runtime_fixtures();
24    fixtures.extend(node_permutation_fixtures());
25    fixtures.extend(json_only_fixtures());
26
27    for fixture in fixtures {
28        let path = out
29            .join(fixture.bucket)
30            .join(format!("{}.json", fixture.name));
31        fs::write(path, fixture.request.to_json_string()?)?;
32    }
33
34    Ok(())
35}