pub struct Cycle {
pub node_ids: Vec<ExternalId>,
pub edge_ids: Vec<EdgeId>,
}Expand description
One canonical simple cycle. The first node is not repeated at the end.
Fields
node_ids: Vec<ExternalId>Canonically rotated node sequence.
edge_ids: Vec<EdgeId>One representative edge per adjacent node pair, including the closing edge from the last node to the first.